//
// Drahtlose Übermittlung mit 433 MHz - Temperatursensor LM35
//


#include <VirtualWire.h>

// Sender Pin (PWM)
int TX_PIN = 11;
// ID Sender
int TX_ID = 3;
// Pin Temperatursensor
int TempPin = 0;
int valTemp = 0;

// Daten als Struct
typedef struct txData
{
  int TX_ID;
  int Data1;
  int Data2;
  int VBat;
};

void setup() 
{
  // Serielle Schnittstelle
  Serial.begin(9600);
  // Drahtlose Schnittstelle, 2000 Bits pro Sekunde
  vw_setup(2000);
  // Daten senden - Start
  vw_set_tx_pin(TX_PIN);
}


void loop()
{
  // Daten senden
  struct txData payload;
  // Adresse des Senders
  payload.TX_ID = TX_ID;
  // Wert Sensor 1 (LM35)
  valTemp=analogRead(TempPin);
  payload.Data1 = valTemp;
  // Wert Sensor 2
  payload.Data2 = 999;
  // Wert Batteriespannung
  payload.VBat=readVCC();
  // Daten senden
  vw_send((uint8_t *)&payload, sizeof(payload));
  vw_wait_tx();
  // warten 2 Sekunden
  delay(2000);
}

long readVCC() 
{
  // A/D-Wandler aktivieren
  bitClear(PRR, PRADC); ADCSRA |= bit(ADEN);
  long result;
  // 1.1-V-Referenz lesen
  // Falls ATtiny84
  #if defined(__AVR_ATtiny84__) 
    ADMUX = _BV(MUX5) | _BV(MUX0);
  #else
    // sonst ATmega328
    ADMUX = _BV(REFS0) | _BV(MUX3) | _BV(MUX2) | _BV(MUX1);
  #endif 
  delay(2);
  ADCSRA |= _BV(ADSC);
  while (bit_is_set(ADCSRA,ADSC));
  result = ADCL;
  result |= ADCH<<8;
  // Umrechnung VCC in mV
  result = 1126400L / result;
  return result;
  // A/D-Wandler deaktivieren
  ADCSRA &= ~ bit(ADEN); bitSet(PRR, PRADC);
}


