//
// Webclient - Daten an MySQL senden
//

#include <SPI.h>
#include <Ethernet.h>
#include "DHT.h"

// Ethernet-Konfiguration
byte mac[] = { 0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xAD};

// IP des externen Servers
IPAddress server(10, 0, 1, 102);

EthernetClient client;

// Datenpin
#define DHTPIN 2

// Sensortyp
#define DHTTYPE DHT11      // DHT11
//#define DHTTYPE DHT22    // DHT 22 (AM2302), AM2321
//#define DHTTYPE DHT21    // DHT 21 (AM2301)     

// Sensor-Objekt erstellen
DHT dht(DHTPIN, DHTTYPE);

long updateTimer;
boolean clientConnected = false;

float tempC;
float hum;

void setup()
{
  Serial.begin(9600);
  Serial.println("Start...");
  // DHT-Sensor starten
  dht.begin();
}

void loop()
{
  // Daten senden
  SendenDaten();
  // Status HTTP-Request einlesen
  checkStatus();
}


void SendenDaten()
{
  // Luftfeuchtigkeit abfragen
  hum = dht.readHumidity();
  // Temperatur in Grad C abfragen
  tempC = dht.readTemperature();
  //tempC=23.44;
  //hum=56.45;

  // Prüfen, ob Sensorabfrage korrekt ist
  if (isnan(hum) || isnan(tempC) ) {
    Serial.println("Fehler beim Abfragen des Sensors");
    return;
  }
  else
  {

  if ((millis() - updateTimer) > 10000)
  {
    Ethernet.begin(mac);
    Serial.println("connecting...");
    delay(1000);
    if (client.connect(server, 80))
    {
      Serial.println("connected");
      client.print("GET /iot/insert-data.php?sensor1=");
      client.print(tempC);
      client.print("&sensor2=");
      client.print(hum);
      client.println(" HTTP/1.0");
      client.println("HOST: 10.0.1.102");
      client.println();
      client.println();
      clientConnected = true;
    }
    else
    {
	Serial.println("connection failed");
    }
    updateTimer = millis();
  }
  }
}

void checkStatus()
{
  if (clientConnected)
  {
    if (client.available())
    {
	char c = client.read();
	Serial.print(c);
    }
    if (!client.connected())
    {
	Serial.println();
	Serial.println("disconnecting.");
	client.stop();
	clientConnected = false;
    }
  }
}
