//
// Abstandmessung mit HC-SR04-Ultraschall-Sensor
// (basierend auf Beispiel Sparkfun)
//

/**
 * HC-SR04 Demo
 * Demonstration of the HC-SR04 Ultrasonic Sensor
 * Date: August 3, 2016
 * License:
 *  Public Domain
 */

// Pins
const int TRIG_PIN = 7;
const int ECHO_PIN = 8;

// Distanzen über 400cm (23200 Mikrosekunden Puls) sind "out of range"
const unsigned int MAX_DIST = 23200;

void setup() 
{
  // Trigger für den Start der Messung
  pinMode(TRIG_PIN, OUTPUT);
  digitalWrite(TRIG_PIN, LOW);

  // Serielle Schnittstelle
  Serial.begin(9600);
}

void loop() 
{
  unsigned long t1;
  unsigned long t2;
  unsigned long pulse_width;
  float cm;
  float inches;


  // Trigger auf HIGH für min. 10 Mikrosekunden
  digitalWrite(TRIG_PIN, HIGH);
  delayMicroseconds(10);
  digitalWrite(TRIG_PIN, LOW);

  // Warten auf Signal an Echo-Pin
  while ( digitalRead(ECHO_PIN) == 0 );

  // Note: the micros() counter will overflow after ~70 min
  // Messung von Pulslänge an Echo-Pin
  t1 = micros();
  while ( digitalRead(ECHO_PIN) == 1);
  t2 = micros();
  pulse_width = t2 - t1;

  // Berechnung von Distanz in cm und inch
  cm = pulse_width / 58.0;
  inches = pulse_width / 148.0;

  // Ausgabe auf serielle Schnittstelle
  if ( pulse_width > MAX_DIST ) 
  {
    Serial.println("ERROR: Out of range");
  } 
  else 
  {
    Serial.print("Abstand: ");
    Serial.print(cm);
    Serial.print(" cm, ");
    Serial.print(inches);
    Serial.println(" in");
  }
    // warten bis nächste Messung
  delay(60);
}
